@@ -1,11 +1,9 @@
 package LWP::Protocol::loopback;
-
+$LWP::Protocol::loopback::VERSION = '6.27';
 use strict;
-use vars qw(@ISA);
 require HTTP::Response;
 
-require LWP::Protocol;
-@ISA = qw(LWP::Protocol);
+use base qw(LWP::Protocol);
 
 sub request {
     my($self, $request, $proxy, $arg, $size, $timeout) = @_;
